unit Unit1;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics,
  Controls, Forms, Dialogs, TeeGDIPlus, ExtCtrls,
  TeEngine, TeeProcs, Chart, Series, StdCtrls;

type
  TForm1 = class(TForm)
    Chart1: TChart;
    Image1: TImage;
    Series1: TAreaSeries;
    Panel1: TPanel;
    chkCreatewithEvents: TCheckBox;
    procedure chkCreatewithEventsClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
  private
    procedure UpdateGapChart(const aRenderWithEvents: boolean);
    procedure ChartAxisLabel(Sender: TChartAxis; Series: TChartSeries;
      ValueIndex: Integer; var LabelText: String);
    procedure GapChartBeforeDrawSeries(Sender: TObject);
    { Private declarations }

  protected
    procedure Resize; override;
  public
    { Public declarations }
  end;

var
  Form1: TForm1;

implementation

uses
  math, TeeConst;

{$R *.dfm}

procedure TForm1.ChartAxisLabel(Sender: TChartAxis;
  Series: TChartSeries; ValueIndex: Integer; var LabelText: String);
var
  lPos: Integer;
begin
  if (Sender.ParentChart.LeftAxis = Sender) and (Sender.Maximum >= 10000) then
  begin
    lPos := Pos(',', LabelText);
    if lPos > 0 then
      LabelText := Copy(LabelText, 1, lPos-1) + 'K';
  end;
end;

procedure TForm1.chkCreatewithEventsClick(Sender: TObject);
begin
  UpdateGapChart(chkCreatewithEvents.Checked);
  Chart1.Repaint;
  UpdateGapChart(chkCreatewithEvents.Checked);
end;

procedure TForm1.GapChartBeforeDrawSeries(Sender: TObject);
var
  lChart: TChart;
  lLeft: Integer;
begin
  //reposition legend
  Assert(sender is TChart);
  lChart := TChart(Sender);
  if (lChart.SeriesCount > 0) and (lChart.Series[0].Count > 0) then
  begin
    lLeft := lChart.Series[0].CalcXPos(1);
    lChart.Legend.Left := lLeft;
  end;
end;

procedure TForm1.Resize;
begin
  inherited;
  UpdateGapChart(chkCreatewithEvents.Checked);
end;

procedure TForm1.UpdateGapChart(const aRenderWithEvents: boolean);
const
  SCALE_FACTOR = 1;
var
  lRect: TRect;
  lBmp: TBitmap;
begin
  if aRenderWithEvents then
  begin
    Chart1.OnGetAxisLabel := ChartAxisLabel;
    Chart1.OnBeforeDrawSeries := GapChartBeforeDrawSeries;{}
  end
  else
  begin
    Chart1.OnGetAxisLabel := nil;
    Chart1.OnBeforeDrawSeries := nil;
  end;

  lRect := Rect(0, 0, Image1.Width, Image1.Height);
  lRect.Right := Ceil(lRect.Right * SCALE_FACTOR);
  lRect.Bottom := Ceil(lRect.Bottom * SCALE_FACTOR);

  lBmp := Chart1.TeeCreateBitmap(clWhite, lRect);
  try
    Image1.Picture.Graphic := lBmp;
  finally
    lBmp.Free;
  end;
end;

procedure TForm1.FormCreate(Sender: TObject);

  function CreateChartSeries(const aTitle: string): TAreaSeries;
  begin
    result := TAreaSeries.Create(self);
    result.ParentChart := Chart1;
    result.AreaLinesPen.Visible := false;
    result.Pen.Visible := false;

    if Chart1.SeriesCount > 1 then
      Chart1.SeriesList.Move(Chart1.SeriesCount - 1, 0);{}

    result.Title := aTitle;
  end;

var
  I: Integer;
  J: Integer;
  lsrs: TChartSeries;
  lValue: Double;
begin
  Caption:=TeeMsg_Version;

  Chart1.FreeAllSeries;

  for I := 1 to 4 do
  begin
    lsrs := CreateChartSeries('Series #' + IntToSTr(I));

    lValue := 1000;
    for J := 0 to 20 do
    begin
      lsrs.AddXY(I, lValue);
      lValue := lValue * 0.03;
    end;
  end;

  Chart1.LeftAxis.Title.Caption := 'Anual Income';
  Chart1.LeftAxis.Title.Font.Size := 10;
  Chart1.BottomAxis.Title.Caption := 'Years in Retirement';{}
  Chart1.View3D := false;
  Chart1.BottomAxis.Title.Font.Size := 10;
  Chart1.Legend.CustomPosition := True;
  Chart1.Legend.Top := 05;
  Chart1.Legend.Left := 05;
end;

end.
